==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/style/values/view-transitions/StyleViewTransitionClass.h <==
/*
 * Copyright (C) 2025 Samuel Weinig <sam@webkit.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ScopedName.h"
#include "StyleValueTypes.h"

namespace WebCore {
namespace Style {

// <single-view-transition-class> = <custom-ident excluding=none>
// https://drafts.csswg.org/css-view-transitions-2/#valdef-view-transition-class-custom-ident
using ViewTransitionClass = ScopedName;

// <view-transition-class-list> = <single-view-transition-class>+
using ViewTransitionClassList = SpaceSeparatedFixedVector<ViewTransitionClass>;

// <'view-transition-class'> = none | <view-transition-class-list>
// https://drafts.csswg.org/css-view-transitions-2/#propdef-view-transition-class
struct ViewTransitionClasses : ListOrNone<ViewTransitionClassList> { using ListOrNone<ViewTransitionClassList>::ListOrNone; };

} // namespace Style
} // namespace WebCore

DEFINE_VARIANT_LIKE_CONFORMANCE(WebCore::Style::ViewTransitionClasses)

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/style/values/view-transitions/StyleViewTransitionClass.h <==
/*
 * Copyright (C) 2025 Samuel Weinig <sam@webkit.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/ScopedName.h>
#include <WebCore/StyleValueTypes.h>

namespace WebCore {
namespace Style {

// <single-view-transition-class> = <custom-ident excluding=none>
// https://drafts.csswg.org/css-view-transitions-2/#valdef-view-transition-class-custom-ident
using ViewTransitionClass = ScopedName;

// <view-transition-class-list> = <single-view-transition-class>+
using ViewTransitionClassList = SpaceSeparatedFixedVector<ViewTransitionClass>;

// <'view-transition-class'> = none | <view-transition-class-list>
// https://drafts.csswg.org/css-view-transitions-2/#propdef-view-transition-class
struct ViewTransitionClasses : ListOrNone<ViewTransitionClassList> { using ListOrNone<ViewTransitionClassList>::ListOrNone; };

} // namespace Style
} // namespace WebCore

DEFINE_VARIANT_LIKE_CONFORMANCE(WebCore::Style::ViewTransitionClasses)
